===============================
brainiac
===============================

.. image:: https://img.shields.io/travis/suyogsoti/client-lib.svg
        :target: https://travis-ci.org/suyogsoti/client-lib

.. image:: https://img.shields.io/pypi/v/client-lib.svg
        :target: https://pypi.python.org/pypi/client-lib


 The client library to make and use brainiac modules.

* Free software: MIT license
* Documentation: (COMING SOON!) https://client-lib.readthedocs.org.

Features
--------

* TODO
